Crate alloy_rpc_types_tenderly

Crate alloy_rpc_types_tenderly 

alloy-rpc-types-tenderly

Types for the Tenderly node’s Ethereum JSON-RPC namespace.

Structs

AssetChange
Information about the assets affected by the transaction.
AssetInfo
Information describing an onchain asset.
BalanceChange
Balance change of an address caused by a transaction.
DecodedValue
Log inputs decoded by the tenderly node.
StateChange
State changes of an address caused by a transaction
StorageSlotChange
Describes the change of a storage slot due to a transaction.
TenderlyDecodeInputResult
Tenderly RPC decode input result.
TenderlyDecodedArgument
Decoded argument for Tenderly decode input.
TenderlyEstimateGasResult
Tenderly RPC estimate gas result.
TenderlyFunctionInput
Function input type for Tenderly function signatures.
TenderlyFunctionSignature
Function signature for Tenderly function signatures.
TenderlyGasPriceResult
Tenderly RPC gas price result.
TenderlyGasPriceTier
Gas price tier information for Tenderly RPC.
TenderlyGasPriceTiers
Gas price tiers for different urgency levels.
TenderlyLog
Logs returned by Tenderly RPC, might be decoded.
TenderlySimulationResult
Tenderly RPC simulation result.
TenderlyStorageChange
Storage change entry for Tenderly get storage changes response.
TenderlyStorageQueryParams
Parameters for Tenderly get storage changes request.
TenderlyTrace
Call trace generated by tenderly.
TenderlyTransactionRangeParams
Parameters for Tenderly get transaction range request.
ValueChange
Describes the change of a value due to a transaction.

Enums

AssetFungibility
Token standard of an asset.
AssetStandard
Token standard of an asset.
ChangeType
Type of asset change.
TenderlyCallType
Types of EVM calls.